Summary: Utilities for managing the second extended (ext2) filesystem.
Name: e2fsprogs
Version: 1.32
Release: 1.3.0
Copyright: GPL
Group: System Environment/Base
Source: ftp://tsx-11.mit.edu/pub/linux/packages/ext2fs/e2fsprogs-%{version}.tar.gz
Patch1: e2fsprogs-1.27-debugfsy2k-gd-1.patch
Buildroot: /var/tmp/%{name}-root
Prereq: /sbin/ldconfig

%description
The e2fsprogs package contains a number of utilities for creating,
checking, modifying and correcting any inconsistencies in second
extended (ext2) filesystems.  E2fsprogs contains e2fsck (used to repair
filesystem inconsistencies after an unclean shutdown), mke2fs (used to
initialize a partition to contain an empty ext2 filesystem), debugfs
(used to examine the internal structure of a filesystem, to manually
repair a corrupted filesystem or to create test cases for e2fsck), tune2fs
(used to modify filesystem parameters) and most of the other core ext2fs
filesystem utilities.

You should install the e2fsprogs package if you need to manage the
performance of an ext2 filesystem.

%package devel
Summary: Ext2 filesystem-specific static libraries and headers.
Group: Development/Libraries
Requires: e2fsprogs
Prereq: /sbin/install-info

%description devel
E2fsprogs-devel contains the libraries and header files needed to
develop second extended (ext2) filesystem-specific programs.

You should install e2fsprogs-devel if you want to develop ext2
filesystem-specific programs.  If you install e2fsprogs-devel, you'll
also want to install e2fsprogs.

%prep
%setup -q
%patch1 -p0

%build
CFLAGS="$RPM_OPT_FLAGS"
%configure --enable-elf-shlibs --enable-jfs-debug
make CFLAGS="$RPM_OPT_FLAGS" libs progs docs

%install
rm -rf $RPM_BUILD_ROOT
export PATH=/sbin:$PATH
make install install-libs DESTDIR="$RPM_BUILD_ROOT" \
	root_sbindir=/sbin root_libdir=/lib root_docdir=%{_docdir}

{ cd $RPM_BUILD_ROOT
  ln -sf ../..%{_root_libdir}/libcom_err.so.2 .%{_libdir}/libcom_err.so
  ln -sf ../..%{_root_libdir}/libe2p.so.2 .%{_libdir}/libe2p.so
  ln -sf ../..%{_root_libdir}/libext2fs.so.2 .%{_libdir}/libext2fs.so
  ln -sf ../..%{_root_libdir}/libss.so.2 .%{_libdir}/libss.so
  ln -sf ../..%{_root_libdir}/libuuid.so.1 .%{_libdir}/libuuid.so
}

%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post devel
/sbin/install-info %{_infodir}/libext2fs.info.gz %{_infodir}/dir

%postun devel
if [ $1 = 0 ]; then
   /sbin/install-info --delete %{_infodir}/libext2fs.info.gz %{_infodir}/dir
fi


%files
%defattr(-,root,root)
%doc README RELEASE-NOTES

%define _root_sbindir	/sbin
%define _root_libdir	/%{_lib}

%attr(0750,root,root)	%{_root_sbindir}/e2fsck
%attr(0750,root,root)	%{_root_sbindir}/e2label
%attr(0750,root,root)	%{_root_sbindir}/tune2fs
%attr(0750,root,root)	%{_root_sbindir}/dumpe2fs
%attr(0750,root,root)	%{_root_sbindir}/fsck
%attr(0750,root,root)	%{_root_sbindir}/fsck.ext2
%attr(0750,root,root)	%{_root_sbindir}/mke2fs
%attr(0750,root,root)	%{_root_sbindir}/debugfs
%attr(0750,root,root)	%{_root_sbindir}/badblocks
%attr(0750,root,root)	%{_bindir}/lsattr
%attr(0750,root,root)	%{_bindir}/chattr
%attr(0750,root,root)	%{_bindir}/uuidgen
%attr(0750,root,root)	%{_sbindir}/mklost+found

%{_root_libdir}/libcom_err.so.*
%{_root_libdir}/libe2p.so.*
%{_root_libdir}/libext2fs.so.*
%{_root_libdir}/libss.so.*
%{_root_libdir}/libuuid.so.*

%doc %{_mandir}/man1/chattr.1*
%doc %{_mandir}/man1/lsattr.1*
%doc %{_mandir}/man1/uuidgen.1*

%doc %{_mandir}/man8/badblocks.8*
%doc %{_mandir}/man8/debugfs.8*
%doc %{_mandir}/man8/dumpe2fs.8*
%doc %{_mandir}/man8/e2fsck.8*
%doc %{_mandir}/man8/e2label.8*
%doc %{_mandir}/man8/fsck.8*
%doc %{_mandir}/man8/mke2fs.8*
%doc %{_mandir}/man8/mklost+found.8*
%doc %{_mandir}/man8/tune2fs.8*

%files devel
%defattr(-,root,root)
%{_infodir}/libext2fs.info*
%{_bindir}/compile_et
%{_bindir}/mk_cmds

%{_libdir}/libcom_err.a
%{_libdir}/libcom_err.so
%{_libdir}/libe2p.a
%{_libdir}/libe2p.so
%{_libdir}/libext2fs.a
%{_libdir}/libext2fs.so
%{_libdir}/libss.a
%{_libdir}/libss.so
%{_libdir}/libuuid.a
%{_libdir}/libuuid.so

%{_datadir}/et
%{_datadir}/ss
%{_includedir}/et
%{_includedir}/ext2fs
%{_includedir}/ss
%{_includedir}/uuid
%doc %{_mandir}/man1/compile_et.1*
%doc %{_mandir}/man3/com_err.3*

%changelog
* Thu Apr 10 2003 Ryan W. Maple <ryan@guardiandigital.com>
- Release 1.3.0
  - Initial build for EnGarde Secure Community 2 (Feint).

* Mon Feb 03 2003 Ryan W. Maple <ryan@guardiandigital.com>
- Release 1.5.0
  - Initial build for EnGarde v1.5 (Thrust).

* Fri Nov 29 2002 Nicholas DeClario <nick@guardiandigital.com>
- Version 1.32, Release 1.2.2
  - Updated to latest version, 1.32

* Wed Apr 17 2002 Nicholas DeClario <nick@guardiandigital.com>
- Version 1.27, Release 1.2.1
  - Upated to latest version, 1.27
  - Ported debugfs GD patch from 1.25 to 1.27

* Fri Feb 01 2002 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.21-WIP-0601, Release 1.2.0
  - Update to version 1.21-WIP so we can do ext3.
  - Removed pre-EnGarde changelog.
  - Removed 'e2fsprogs-1.18-mountlabel.patch'.

* Tue Aug 07 2001 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.18, Release 1.1.0
  - Initial build for EnGarde v1.1 (Balestra).

* Sat Oct 28 2000 Dave Wreski <dave@guardiandigital.com>
- rebuild to include RH bug fixes
- atttempted FHS

* Thu Jul 06 2000 Pete O'Hara <pete@guardiandigital.com>
- removed world access for most of the executables for
	Guaridian Digital Lockbox
